Re: [PATCH 9/9] Audit: Final renamings and cleanup

2008-03-03 Thread James Morris
On Sat, 1 Mar 2008, Ahmed S. Darwish wrote:

> Rename the se_str and se_rule audit fields elements to
> lsm_str and lsm_rule to avoid confusion.
> 
> Signed-off-by: Casey Schaufler <[EMAIL PROTECTED]>
> Signed-off-by: Ahmed S. Darwish <[EMAIL PROTECTED]>

Acked-by: James Morris <[EMAIL PROTECTED]>


-- 
James Morris
<[EMAIL PROTECTED]>

--
Linux-audit mailing list
Linux-audit@redhat.com
https://www.redhat.com/mailman/listinfo/linux-audit


[PATCH 9/9] Audit: Final renamings and cleanup

2008-03-03 Thread Ahmed S. Darwish
Rename the se_str and se_rule audit fields elements to
lsm_str and lsm_rule to avoid confusion.

Signed-off-by: Casey Schaufler <[EMAIL PROTECTED]>
Signed-off-by: Ahmed S. Darwish <[EMAIL PROTECTED]>
---

 include/linux/audit.h |4 ++--
 kernel/auditfilter.c  |   40 
 kernel/auditsc.c  |   12 ++--
 3 files changed, 28 insertions(+), 28 deletions(-)

Woo, hooo .. That was fun ;)

diff --git a/include/linux/audit.h b/include/linux/audit.h
index 3367c80..a35678e 100644
--- a/include/linux/audit.h
+++ b/include/linux/audit.h
@@ -377,8 +377,8 @@ struct audit_field {
u32 type;
u32 val;
u32 op;
-   char*se_str;
-   void*se_rule;
+   char*lsm_str;
+   void*lsm_rule;
 };
 
 #define AUDITSC_INVALID 0
diff --git a/kernel/auditfilter.c b/kernel/auditfilter.c
index 7c69cb5..28fef6b 100644
--- a/kernel/auditfilter.c
+++ b/kernel/auditfilter.c
@@ -139,8 +139,8 @@ static inline void audit_free_rule(struct audit_entry *e)
if (e->rule.fields)
for (i = 0; i < e->rule.field_count; i++) {
struct audit_field *f = &e->rule.fields[i];
-   kfree(f->se_str);
-   security_audit_rule_free(f->se_rule);
+   kfree(f->lsm_str);
+   security_audit_rule_free(f->lsm_rule);
}
kfree(e->rule.fields);
kfree(e->rule.filterkey);
@@ -554,8 +554,8 @@ static struct audit_entry *audit_data_to_entry(struct 
audit_rule_data *data,
f->op = data->fieldflags[i] & AUDIT_OPERATORS;
f->type = data->fields[i];
f->val = data->values[i];
-   f->se_str = NULL;
-   f->se_rule = NULL;
+   f->lsm_str = NULL;
+   f->lsm_rule = NULL;
switch(f->type) {
case AUDIT_PID:
case AUDIT_UID:
@@ -598,7 +598,7 @@ static struct audit_entry *audit_data_to_entry(struct 
audit_rule_data *data,
entry->rule.buflen += f->val;
 
err = security_audit_rule_init(f->type, f->op, str,
-  (void **)&f->se_rule);
+  (void **)&f->lsm_rule);
/* Keep currently invalid fields around in case they
 * become valid after a policy reload. */
if (err == -EINVAL) {
@@ -610,7 +610,7 @@ static struct audit_entry *audit_data_to_entry(struct 
audit_rule_data *data,
kfree(str);
goto exit_free;
} else
-   f->se_str = str;
+   f->lsm_str = str;
break;
case AUDIT_WATCH:
str = audit_unpack_string(&bufp, &remain, f->val);
@@ -754,7 +754,7 @@ static struct audit_rule_data *audit_krule_to_data(struct 
audit_krule *krule)
case AUDIT_OBJ_LEV_LOW:
case AUDIT_OBJ_LEV_HIGH:
data->buflen += data->values[i] =
-   audit_pack_string(&bufp, f->se_str);
+   audit_pack_string(&bufp, f->lsm_str);
break;
case AUDIT_WATCH:
data->buflen += data->values[i] =
@@ -806,7 +806,7 @@ static int audit_compare_rule(struct audit_krule *a, struct 
audit_krule *b)
case AUDIT_OBJ_TYPE:
case AUDIT_OBJ_LEV_LOW:
case AUDIT_OBJ_LEV_HIGH:
-   if (strcmp(a->fields[i].se_str, b->fields[i].se_str))
+   if (strcmp(a->fields[i].lsm_str, b->fields[i].lsm_str))
return 1;
break;
case AUDIT_WATCH:
@@ -862,28 +862,28 @@ out:
return new;
 }
 
 /* Duplicate LSM field information.  The se_rule is opaque, so must be
  * re-initialized. */
 static inline int audit_dupe_lsm_field(struct audit_field *df,
   struct audit_field *sf)
 {
int ret = 0;
-   char *se_str;
+   char *lsm_str;
 
-   /* our own copy of se_str */
-   se_str = kstrdup(sf->se_str, GFP_KERNEL);
-   if (unlikely(!se_str))
+   /* our own copy of lsm_str */
+   lsm_str = kstrdup(sf->lsm_str, GFP_KERNEL);
+   if (unlikely(!lsm_str))
return -ENOMEM;
-   df->se_str = se_str;
+   df->lsm_str = lsm_str;
 
-   /* our own (refreshed) copy of se_rule */
-   ret = security_audit_rule_
@@ -862,28 +862,28 @@ out:
 }
 
-/* Duplicate LSM field information.  The se_rule is opaque, so must be
+/* Duplicate LSM field information.  The lsm_rule is opaque, so must be
  * re-initialized. */
 static inline int audit_dupe_lsm_field(struct audit_field *df,